Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Glacier.

Actions, resources, and condition keys for Amazon Glacier - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Glacier

Amazon Glacier (service prefix: `glacier` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon Glacier
- Resource types defined by Amazon Glacier
- Condition keys for Amazon Glacier

## Actions defined by Amazon Glacier

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AbortMultipartUpload | Aborts a multipart upload identified by the upload ID | Write | vault* |  |
AbortVaultLock | Aborts the vault locking process if the vault lock is not in the Locked state | Permissions management | vault* |  |
AddTagsToVault | Adds the specified tags to a vault | Tagging | vault* |  |
CompleteMultipartUpload | Completes a multipart upload process | Write | vault* |  |
CompleteVaultLock | Completes the vault locking process | Permissions management | vault* |  |
CreateVault | Creates a new vault with the specified name | Write | vault* |  |
DeleteArchive | Deletes an archive from a vault | Write | vault* |  |
| glacier:ArchiveAgeInDays |
DeleteVault | Deletes a vault | Write | vault* |  |
DeleteVaultAccessPolicy | Deletes the access policy associated with the specified vault | Permissions management | vault* |  |
DeleteVaultNotifications | Deletes the notification configuration set for a vault | Write | vault* |  |
DescribeJob | Returns information about a job you previously initiated | Read | vault* |  |
DescribeVault | Returns information about a vault | Read | vault* |  |
GetDataRetrievalPolicy | Returns the current data retrieval policy for the account and region specified in the GET request | Read |  |  |
GetJobOutput | Downloads the output of the job you initiated | Read | vault* |  |
GetVaultAccessPolicy | Retrieves the access-policy subresource set on the vault | Read | vault* |  |
GetVaultLock | Retrieves attributes from the lock-policy subresource set on the specified vault | Read | vault* |  |
GetVaultNotifications | Retrieves the notification-configuration subresource set on the vault | Read | vault* |  |
InitiateJob | Initiates a job of the specified type | Write | vault* |  |
| glacier:ArchiveAgeInDays |
InitiateMultipartUpload | Initiates a multipart upload | Write | vault* |  |
InitiateVaultLock | Initiates the vault locking process | Permissions management | vault* |  |
ListJobs | Lists jobs for a vault that are in-progress and jobs that have recently finished | List | vault* |  |
ListMultipartUploads | Lists in-progress multipart uploads for the specified vault | List | vault* |  |
ListParts | Lists the parts of an archive that have been uploaded in a specific multipart upload | List | vault* |  |
ListProvisionedCapacity | This operation lists the provisioned capacity for the specified AWS account. | List |  |  |
ListTagsForVault | Lists all the tags attached to a vault | List | vault* |  |
ListVaults | Lists all vaults | List |  |  |
PurchaseProvisionedCapacity | This operation purchases a provisioned capacity unit for an AWS account. | Write |  |  |
RemoveTagsFromVault | Removes one or more tags from the set of tags attached to a vault | Tagging | vault* |  |
SetDataRetrievalPolicy | Sets and then enacts a data retrieval policy in the region specified in the PUT request | Permissions management |  |  |
SetVaultAccessPolicy | Configures an access policy for a vault and will overwrite an existing policy | Permissions management | vault* |  |
SetVaultNotifications | Configures vault notifications | Write | vault* |  |
UploadArchive | Adds an archive to a vault | Write | vault* |  |
UploadMultipartPart | Uploads a part of an archive | Write | vault* |  |

## Resource types defined by Amazon Glacier

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
vault | `arn:$ { Partition}:glacier:$ { Region}:$ { Account}:vaults/$ { VaultName}` |

## Condition keys for Amazon Glacier

Amazon Glacier defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
glacier:ArchiveAgeInDays | How long an archive has been stored in the vault, in days. | String
glacier:ResourceTag/ | A customer-defined tag. | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.